@@ -1,5 +1,6 @@
 // -*- C++ -*-
 #include <wibble/mixin.h>
+#include <string>
 
 #ifndef EPT_TOKEN_H
 #define EPT_TOKEN_H
@@ -24,6 +25,14 @@ struct Token : wibble::mixin::Comparable< Token > {
                             _id.size() : _id.find( '_' ) );
     }
 
+    bool isDesktop() const {
+        return std::string( _id, 0, 8 ) == "desktop:";
+    }
+
+    std::string desktop() const {
+        return isDesktop() ? std::string( _id, 8, _id.size() ) : "";
+    }
+
     bool hasVersion() const {
         return version() != "";
     }
